@@ -26,6 +26,7 @@ sub render {
     my ($self, $template, $tokens) = @_;
 
     my $content = eval {
+        $_engine->prepend("my \$t = \$_[0];");
         $_engine->render_file($template, $tokens)
     };
 
@@ -47,28 +48,27 @@ Dancer::Template::MojoTemplate - Mojo::Template wrapper for Dancer
 
 =head1 VERSION
 
-version 0.2.0
+version 0.01
 
 =head1 DESCRIPTION
 
-This is an interface between Dancer's template engine abstraction layer and
-the L<Mojo::Template> module.
+This class is an interface between Dancer's template engine abstraction layer
+and the L<Mojo::Template> module.
 
 In order to use this engine, use the template setting:
 
     template: mojo_template
 
-This can be done in your config.yml file or directly in your app code with
-the B<set> keyword.
+This can be done in your config.yml file or directly in your app code with the
+B<set> keyword.
 
 You can configure L<Mojo::Template> :
 
-    template: 'mojo_template'
+    template: mojo_template
     engines:
         mojo_template:
-            auto_escape: 1
-            trim_mark: '-'
-            prepend: 'my $t = $_[0];'
+            trim_mark    => '-',
+            auto_escape  => 1,
 
 =head1 SEE ALSO
 
@@ -86,4 +86,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
